..
    SPDX-FileCopyrightText: 2024 Alec Delaney
    SPDX-License-Identifier: GPL-3.0-or-later

CLI
===

Below is a shell script showing how the CLI can be used.  Additional information on the CLI can be found using ``cronberry --help``.

.. literalinclude:: ../examples/example.sh
